buildArgParser method

  1. @override
void buildArgParser(
  1. ArgParser argParser
)
override

构建自己的命令参数

Implementation

@override
void buildArgParser(ArgParser argParser) {
   argParser.addOption('flavor', abbr: 'f', help: '''
Build a custom app flavor as defined by platform-specific build setup.
Supports the use of product flavors in Android Gradle scripts, and the use of custom Xcode schemes.
''');
}