LogLevel class final

日志级别

level 100-299 框架预留 300-599 应用可用

Available extensions

Constructors

LogLevel(int level, String name, {String? short, String? color, String? bgColor})
const
LogLevel.debug()
factory
LogLevel.error()
factory
LogLevel.fatal()
factory
LogLevel.info()
factory
LogLevel.off()
factory
LogLevel.on()
factory
LogLevel.verbose()
factory
LogLevel.warn()
factory

Properties

bgColor String?
final
color String?
final
hashCode int
The hash code for this object.
no setterinherited
level int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator <(LogLevel other) bool

Available on LogLevel, provided by the LogLevelExt extension

operator <=(LogLevel other) bool

Available on LogLevel, provided by the LogLevelExt extension

operator ==(Object other) bool
The equality operator.
inherited
operator >(LogLevel other) bool

Available on LogLevel, provided by the LogLevelExt extension

operator >=(LogLevel other) bool

Available on LogLevel, provided by the LogLevelExt extension