LogRecord class

Available extensions

Constructors

LogRecord(LogLevel level, String name, dynamic message, Object? error, StackTrace? stackTrace)

Properties

dateTime DateTime
final
error Object?
final
hashCode int
The hash code for this object.
no setterinherited
level LogLevel
final
message → dynamic
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber int
final
stackTrace StackTrace?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMultiLineString() List<String>

Available on LogRecord, provided by the LogRecordExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited