LogStrategy class abstract

日志策略

Constructors

LogStrategy(LogLevel level)

Properties

hashCode int
The hash code for this object.
no setterinherited
level LogLevel
日志打印级别, 低于该级别的日志不打印
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatter(LogRecord record) String
日志格式化
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(LogRecord record) → void
日志输出
shouldLog(LogRecord record) bool
是否需要打印日志
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited