LruMap<K, V> class

Constructors

LruMap()
LruMap.from(Map<K, V> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
keys Iterable<K>
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable<V>
no setter

Methods

addAll(Map<K, V> other) → void
clear() → void
containsKey(K key) bool
containsValue(V value) bool
forEach(void action(K key, V value)) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(K key, V ifAbsent()) → V
remove(K key) → V?
removeFirst() → V?
removeLast() → V?
removeWhere(bool test(K key, V value)) → void
toString() String
A string representation of this object.
override
update(K key, V update(V value), {V ifAbsent()?}) → V
updateAll(V update(K key, V value)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → V?
operator []=(K key, V value) → void